Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1496)

Unified Diff: third_party/WebKit/Source/core/layout/LayoutBox.cpp

Issue 2688413005: Check paint offset change after updatePaintOffsetTransform (Closed)
Patch Set: Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | third_party/WebKit/Source/core/layout/LayoutObject.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: third_party/WebKit/Source/core/layout/LayoutBox.cpp
diff --git a/third_party/WebKit/Source/core/layout/LayoutBox.cpp b/third_party/WebKit/Source/core/layout/LayoutBox.cpp
index e0126396032491a8a71876ef69f4bec95f6e2f0d..2f4426d145cd2eb6969840fd571e711a69bda304 100644
--- a/third_party/WebKit/Source/core/layout/LayoutBox.cpp
+++ b/third_party/WebKit/Source/core/layout/LayoutBox.cpp
@@ -1704,10 +1704,12 @@ ResourcePriority LayoutBox::computeResourcePriority() const {
}
void LayoutBox::locationChanged() {
- // The location may change because of layout of other objects. Should check
- // this object for paint invalidation.
- if (!needsLayout())
+ // The location may change because of layout of other objects. Should update
+ // paint properties and check for paint invalidation.
+ if (!needsLayout()) {
setMayNeedPaintInvalidation();
+ setNeedsPaintPropertyUpdate();
+ }
}
void LayoutBox::sizeChanged() {
« no previous file with comments | « no previous file | third_party/WebKit/Source/core/layout/LayoutObject.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698